package com.mdd.admin.validate.system;

import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.util.List;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("系统管理员创建参数")
public class SystemAdminCreateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @ApiModelProperty(
      value = "登录账号",
      required = true
   )
   private @NotEmpty(
   message = "账号不能为空"
) @Length(
   min = 2,
   max = 20,
   message = "账号必须在2~20个字符内"
) String username;
   private String nickname;
   @ApiModelProperty(
      value = "登录密码",
      required = true
   )
   private @NotEmpty(
   message = "密码不能为空"
) @Length(
   min = 6,
   max = 32,
   message = "密码必须在6~32个字符内"
) String password;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "是否禁用",
      required = true
   )
   private Integer isDisable;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "支持多端",
      required = true
   )
   private @NotNull(
   message = "请选择是否支持多端登录"
) Integer isMultipoint;
   @ApiModelProperty("权限标识")
   private String perms;
   @ApiModelProperty("指标数量")
   private Integer goal;
   @ApiModelProperty("轮询优先级")
   private Integer loopLevel;
   @ApiModelProperty(
      value = "排序",
      required = true
   )
   private @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer sort = 0;
   @ApiModelProperty("头像")
   private String avatar = "";
   @ApiModelProperty(
      value = "角色ID",
      required = true
   )
   private @NotNull(
   message = "请选择角色"
) Integer roleIds;
   @ApiModelProperty("部门ID")
   private List<Integer> deptIds;
   @ApiModelProperty("岗位ID")
   private List<Integer> postIds;

   public String getUsername() {
      return this.username;
   }

   public String getNickname() {
      return this.nickname;
   }

   public String getPassword() {
      return this.password;
   }

   public Integer getIsDisable() {
      return this.isDisable;
   }

   public @NotNull(
   message = "请选择是否支持多端登录"
) Integer getIsMultipoint() {
      return this.isMultipoint;
   }

   public String getPerms() {
      return this.perms;
   }

   public Integer getGoal() {
      return this.goal;
   }

   public Integer getLoopLevel() {
      return this.loopLevel;
   }

   public Integer getSort() {
      return this.sort;
   }

   public String getAvatar() {
      return this.avatar;
   }

   public @NotNull(
   message = "请选择角色"
) Integer getRoleIds() {
      return this.roleIds;
   }

   public List<Integer> getDeptIds() {
      return this.deptIds;
   }

   public List<Integer> getPostIds() {
      return this.postIds;
   }

   public void setUsername(String username) {
      this.username = username;
   }

   public void setNickname(String nickname) {
      this.nickname = nickname;
   }

   public void setPassword(String password) {
      this.password = password;
   }

   public void setIsDisable(Integer isDisable) {
      this.isDisable = isDisable;
   }

   public void setIsMultipoint(@NotNull(
   message = "请选择是否支持多端登录"
) Integer isMultipoint) {
      this.isMultipoint = isMultipoint;
   }

   public void setPerms(String perms) {
      this.perms = perms;
   }

   public void setGoal(Integer goal) {
      this.goal = goal;
   }

   public void setLoopLevel(Integer loopLevel) {
      this.loopLevel = loopLevel;
   }

   public void setSort(Integer sort) {
      this.sort = sort;
   }

   public void setAvatar(String avatar) {
      this.avatar = avatar;
   }

   public void setRoleIds(@NotNull(
   message = "请选择角色"
) Integer roleIds) {
      this.roleIds = roleIds;
   }

   public void setDeptIds(List<Integer> deptIds) {
      this.deptIds = deptIds;
   }

   public void setPostIds(List<Integer> postIds) {
      this.postIds = postIds;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof SystemAdminCreateValidate)) {
         return false;
      } else {
         SystemAdminCreateValidate other = (SystemAdminCreateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label167: {
               Object this$isDisable = this.getIsDisable();
               Object other$isDisable = other.getIsDisable();
               if (this$isDisable == null) {
                  if (other$isDisable == null) {
                     break label167;
                  }
               } else if (this$isDisable.equals(other$isDisable)) {
                  break label167;
               }

               return false;
            }

            Object this$isMultipoint = this.getIsMultipoint();
            Object other$isMultipoint = other.getIsMultipoint();
            if (this$isMultipoint == null) {
               if (other$isMultipoint != null) {
                  return false;
               }
            } else if (!this$isMultipoint.equals(other$isMultipoint)) {
               return false;
            }

            label153: {
               Object this$goal = this.getGoal();
               Object other$goal = other.getGoal();
               if (this$goal == null) {
                  if (other$goal == null) {
                     break label153;
                  }
               } else if (this$goal.equals(other$goal)) {
                  break label153;
               }

               return false;
            }

            Object this$loopLevel = this.getLoopLevel();
            Object other$loopLevel = other.getLoopLevel();
            if (this$loopLevel == null) {
               if (other$loopLevel != null) {
                  return false;
               }
            } else if (!this$loopLevel.equals(other$loopLevel)) {
               return false;
            }

            label139: {
               Object this$sort = this.getSort();
               Object other$sort = other.getSort();
               if (this$sort == null) {
                  if (other$sort == null) {
                     break label139;
                  }
               } else if (this$sort.equals(other$sort)) {
                  break label139;
               }

               return false;
            }

            Object this$roleIds = this.getRoleIds();
            Object other$roleIds = other.getRoleIds();
            if (this$roleIds == null) {
               if (other$roleIds != null) {
                  return false;
               }
            } else if (!this$roleIds.equals(other$roleIds)) {
               return false;
            }

            label125: {
               Object this$username = this.getUsername();
               Object other$username = other.getUsername();
               if (this$username == null) {
                  if (other$username == null) {
                     break label125;
                  }
               } else if (this$username.equals(other$username)) {
                  break label125;
               }

               return false;
            }

            label118: {
               Object this$nickname = this.getNickname();
               Object other$nickname = other.getNickname();
               if (this$nickname == null) {
                  if (other$nickname == null) {
                     break label118;
                  }
               } else if (this$nickname.equals(other$nickname)) {
                  break label118;
               }

               return false;
            }

            Object this$password = this.getPassword();
            Object other$password = other.getPassword();
            if (this$password == null) {
               if (other$password != null) {
                  return false;
               }
            } else if (!this$password.equals(other$password)) {
               return false;
            }

            label104: {
               Object this$perms = this.getPerms();
               Object other$perms = other.getPerms();
               if (this$perms == null) {
                  if (other$perms == null) {
                     break label104;
                  }
               } else if (this$perms.equals(other$perms)) {
                  break label104;
               }

               return false;
            }

            label97: {
               Object this$avatar = this.getAvatar();
               Object other$avatar = other.getAvatar();
               if (this$avatar == null) {
                  if (other$avatar == null) {
                     break label97;
                  }
               } else if (this$avatar.equals(other$avatar)) {
                  break label97;
               }

               return false;
            }

            Object this$deptIds = this.getDeptIds();
            Object other$deptIds = other.getDeptIds();
            if (this$deptIds == null) {
               if (other$deptIds != null) {
                  return false;
               }
            } else if (!this$deptIds.equals(other$deptIds)) {
               return false;
            }

            Object this$postIds = this.getPostIds();
            Object other$postIds = other.getPostIds();
            if (this$postIds == null) {
               if (other$postIds != null) {
                  return false;
               }
            } else if (!this$postIds.equals(other$postIds)) {
               return false;
            }

            return true;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof SystemAdminCreateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $isDisable = this.getIsDisable();
      result = result * 59 + ($isDisable == null ? 43 : $isDisable.hashCode());
      Object $isMultipoint = this.getIsMultipoint();
      result = result * 59 + ($isMultipoint == null ? 43 : $isMultipoint.hashCode());
      Object $goal = this.getGoal();
      result = result * 59 + ($goal == null ? 43 : $goal.hashCode());
      Object $loopLevel = this.getLoopLevel();
      result = result * 59 + ($loopLevel == null ? 43 : $loopLevel.hashCode());
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $roleIds = this.getRoleIds();
      result = result * 59 + ($roleIds == null ? 43 : $roleIds.hashCode());
      Object $username = this.getUsername();
      result = result * 59 + ($username == null ? 43 : $username.hashCode());
      Object $nickname = this.getNickname();
      result = result * 59 + ($nickname == null ? 43 : $nickname.hashCode());
      Object $password = this.getPassword();
      result = result * 59 + ($password == null ? 43 : $password.hashCode());
      Object $perms = this.getPerms();
      result = result * 59 + ($perms == null ? 43 : $perms.hashCode());
      Object $avatar = this.getAvatar();
      result = result * 59 + ($avatar == null ? 43 : $avatar.hashCode());
      Object $deptIds = this.getDeptIds();
      result = result * 59 + ($deptIds == null ? 43 : $deptIds.hashCode());
      Object $postIds = this.getPostIds();
      result = result * 59 + ($postIds == null ? 43 : $postIds.hashCode());
      return result;
   }

   public String toString() {
      return "SystemAdminCreateValidate(username=" + this.getUsername() + ", nickname=" + this.getNickname() + ", password=" + this.getPassword() + ", isDisable=" + this.getIsDisable() + ", isMultipoint=" + this.getIsMultipoint() + ", perms=" + this.getPerms() + ", goal=" + this.getGoal() + ", loopLevel=" + this.getLoopLevel() + ", sort=" + this.getSort() + ", avatar=" + this.getAvatar() + ", roleIds=" + this.getRoleIds() + ", deptIds=" + this.getDeptIds() + ", postIds=" + this.getPostIds() + ")";
   }
}
